.. -*- mode: rst; fill-column: 79 -*-
.. ex: set sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the NiBabel package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. _chap_devdiscuss:

*********************
Developer discussions
*********************

Some miscellaneous documents on background, future development and work in
progress.

.. toctree::
    :maxdepth: 2

    spm_use
    modified_images
    data_pkg_design
